summaryrefslogtreecommitdiff
path: root/mpn/m88k/sub_n.s
diff options
context:
space:
mode:
Diffstat (limited to 'mpn/m88k/sub_n.s')
-rw-r--r--mpn/m88k/sub_n.s6
1 files changed, 3 insertions, 3 deletions
diff --git a/mpn/m88k/sub_n.s b/mpn/m88k/sub_n.s
index 7dfffc980..d6ffa0941 100644
--- a/mpn/m88k/sub_n.s
+++ b/mpn/m88k/sub_n.s
@@ -1,4 +1,4 @@
; mc88100 __mpn_sub -- Subtract two limb vectors of the same length > 0 and
; store difference in a third limb vector.
; Copyright (C) 1992, 1994, 1996 Free Software Foundation, Inc.
@@ -36,8 +36,8 @@
text
align 16
- global ___mpn_sub_n
-___mpn_sub_n:
+ global ___gmpn_sub_n
+___gmpn_sub_n:
ld r6,r3,0 ; read first limb from s1_ptr
extu r10,r5,3
ld r7,r4,0 ; read first limb from s2_ptr
@@ -1,4 +1,4 @@
-; mc88100 __mpn_sub -- Subtract two limb vectors of the same length > 0 and
+; mc88100 __gmpn_sub -- Subtract two limb vectors of the same length > 0 and
; store difference in a third limb vector.
; Copyright (C) 1992, 1994, 1996 Free Software Foundation, Inc.